@@ -1,5 +1,5 @@
 import logging
-from typing import Dict, Union, List, Tuple, Optional, Iterable, SupportsInt
+from typing import Dict, Union, List, Tuple, Optional, Iterable, SupportsInt, Set
 from uuid import UUID
 
 from slapp_py.core_classes.bracket import Bracket
@@ -205,7 +205,7 @@ class SlappResponseObject:
         """
         return self.get_brackets_for_player(p).get(source_id.__str__(), [])
 
-    def get_placements_by_place(self, p: Player, place: Union[int, SupportsInt] = 1) -> List[Tuple[SimpleSource, Bracket]]:
+    def get_placements_by_place(self, p: Player, place: Union[int, SupportsInt] = 1) -> List[Tuple[SimpleSource, Bracket, Set[UUID]]]:
         """
         Gets a list of SimpleSources and their brackets where the specified player has
         come in the given place (first by default).
@@ -222,7 +222,9 @@ class SlappResponseObject:
                     first_place_ids = [player_id.__str__() for player_id in
                                        bracket.placements.players_by_placement[1]]
                     if p.guid.__str__() in first_place_ids:
-                        result.append((self.sources[source_id], bracket))
+                        from slapp_py.core_classes.builtins import NoTeam
+                        team = bracket.placements.teams_by_placement.get(place, set(NoTeam.guid))
+                        result.append((self.sources[source_id], bracket, team))
         return result
 
     def get_low_ink_placements(self, p: Player) -> List[Tuple[int, str, str]]:
